# Cognitive Data Transformer (CDT)

CDT is a versatile library designed to process and analyze multi-modal data (text, images, audio, and documents) and generate actionable insights using advanced AI tools.

## Installation

To install the CDT library, run the following command:

